@@ -15,8 +15,15 @@ function choose_language(l){
         case "latin":
             return all_languages.latin;
             break;
+        case "chinese_simplified":
+            return all_languages.chinese_simplified;
+            break;
+        case "chinese_traditional":
+            return all_languages.chinese_traditional;
+            break;
     }
-    return "broken_language";
+    alert("It looks like your language {" + l + "} is broken , defaulting to English");
+    return all_languages.english;;
 }
 
 function reload_DOM_language(lang){
@@ -32,7 +39,7 @@ function reload_DOM_language(lang){
 
     $("#edit_dropdown_a").html(lang.edit_menu + '\n<i class="fa fa-caret-down"></i>'); // Edit Menu
     $("#create_cell_a").text(lang.create_cell);
-    $("#duplicate_cell_a").text(lang.dupe_cell);
+    $("#dupe_cell_a").text(lang.dupe_cell);
     $("#delete_cell_a").text(lang.delete_cell);
 
     $("#cell_dropdown_a").html(lang.cell_menu + '\n<i class="fa fa-caret-down"></i>'); // Cell Menu
@@ -1268,4 +1275,4 @@ var debounce_func = debounce(function(){
 
 window.setInterval(function(){
     debounce_func();
-}, 100);
\ No newline at end of file
+}, 100);
